[llvm-commits] [llvm] r66585 - /llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp

Bill Wendling isanbard at gmail.com
Tue Mar 10 14:59:25 PDT 2009


Author: void
Date: Tue Mar 10 16:59:25 2009
New Revision: 66585

URL: http://llvm.org/viewvc/llvm-project?rev=66585&view=rev
Log:
- Fix misspelled method name.
- Remove unused method.

Modified:
    llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp

Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp?rev=66585&r1=66584&r2=66585&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfWriter.cpp Tue Mar 10 16:59:25 2009
@@ -1303,10 +1303,10 @@
   std::vector<FunctionDebugFrameInfo> DebugFrames;
 
 private:
   /// getSourceDirsectoryAndFileIds - Return the directory and file ids that
   /// maps to the source id. Source id starts at 1.
   std::pair<unsigned, unsigned>
-  getSourceDirsectoryAndFileIds(unsigned SId) const {
+  getSourceDirectoryAndFileIds(unsigned SId) const {
     return SourceIds[SId-1];
   }
 
@@ -1329,7 +1329,6 @@
   }
 
   /// getNumSourceIds - Return the number of unique source ids.
-  ///
   unsigned getNumSourceIds() const {
     return SourceIds.size();
   }
@@ -2503,7 +2502,7 @@
     // Emit files.
     for (unsigned SI = 1, SE = getNumSourceIds()+1; SI != SE; ++SI) {
       // Remember source id starts at 1.
-      std::pair<unsigned, unsigned> Id = getSourceDirsectoryAndFileIds(SI);
+      std::pair<unsigned, unsigned> Id = getSourceDirectoryAndFileIds(SI);
       Asm->EmitString(getSourceFileName(Id.second));
       Asm->EOL("Source");
       Asm->EmitULEB128Bytes(Id.first);
@@ -2545,7 +2544,7 @@
           Asm->EOL();
         else {
           std::pair<unsigned, unsigned> SourceID =
-            getSourceDirsectoryAndFileIds(LineInfo.getSourceID());
+            getSourceDirectoryAndFileIds(LineInfo.getSourceID());
           O << '\t' << TAI->getCommentString() << ' '
             << getSourceDirectoryName(SourceID.first) << ' '
             << getSourceFileName(SourceID.second)
@@ -3083,7 +3082,7 @@
     if (TAI->hasDotLocAndDotFile()) {
       for (unsigned i = 1, e = getNumSourceIds()+1; i != e; ++i) {
         // Remember source id starts at 1.
-        std::pair<unsigned, unsigned> Id = getSourceDirsectoryAndFileIds(i);
+        std::pair<unsigned, unsigned> Id = getSourceDirectoryAndFileIds(i);
         sys::Path FullPath(getSourceDirectoryName(Id.first));
         bool AppendOk =
           FullPath.appendComponent(getSourceFileName(Id.second));
@@ -3339,11 +3338,6 @@
     return Lines.size();
   }
                             
-  /// getNumSourceFiles - Return the number of source files in the debug info.
-  unsigned getNumSourceFiles() const {
-    return SourceFileNames.size();
-  }
-
   /// getOrCreateSourceID - Public version of GetOrCreateSourceID. This can be
   /// timed. Look up the source id with the given directory and source file
   /// names. If none currently exists, create a new id and insert it in the
@@ -1303,10 +1303,10 @@
 
 private:
-  /// getSourceDirsectoryAndFileIds - Return the directory and file ids that
+  /// getSourceDirectoryAndFileIds - Return the directory and file ids that
   /// maps to the source id. Source id starts at 1.
   std::pair<unsigned, unsigned>





More information about the llvm-commits mailing list